@@ -94,11 +94,11 @@ def saml_response_from_idp():
             ApiError(str(e), 500)
 
     if user.status != 'active':
-        raise ApiError('User {} is not active'.format(email), 403)
+        raise ApiError(f'User {email} is not active', 403)
 
     groups = identity.get('groups', [])
     if not_authorized('ALLOWED_SAML2_GROUPS', groups) or not_authorized('ALLOWED_EMAIL_DOMAINS', groups=[user.domain]):
-        message = {'status': 'error', 'message': 'User {} is not authorized'.format(email)}
+        message = {'status': 'error', 'message': f'User {email} is not authorized'}
         return render_template('auth/saml2.html', message=message, origin=origin), 403
 
     user.update_last_login()
