@@ -12,6 +12,7 @@ from alerta.app import alarm_model
 from alerta.database.base import Database
 from alerta.exceptions import NoCustomerMatch
 from alerta.models.enums import ADMIN_SCOPES
+from alerta.models.heartbeat import HeartbeatStatus
 from alerta.utils.format import DateTime
 from alerta.utils.response import absolute_url
 
@@ -101,17 +102,17 @@ class Backend(Database):
                     break
                 else:
                     backoff = 2 ** retry
-                    print('Retry attempt {}/{} (wait={}s)...'.format(retry, MAX_RETRIES, backoff))
+                    print(f'Retry attempt {retry}/{MAX_RETRIES} (wait={backoff}s)...')
                     time.sleep(backoff)
 
         if conn:
             return conn
         else:
-            raise RuntimeError('Database connect error. Failed to connect after {} retries.'.format(MAX_RETRIES))
+            raise RuntimeError(f'Database connect error. Failed to connect after {MAX_RETRIES} retries.')
 
     @staticmethod
     def _adapt_datetime(dt):
-        return AsIs('%s' % adapt(DateTime.iso8601(dt)))
+        return AsIs(f'{adapt(DateTime.iso8601(dt))}')
 
     @property
     def name(self):
@@ -138,7 +139,7 @@ class Backend(Database):
         conn = self.connect()
         cursor = conn.cursor()
         for table in ['alerts', 'blackouts', 'customers', 'groups', 'heartbeats', 'keys', 'metrics', 'perms', 'users']:
-            cursor.execute('DROP TABLE IF EXISTS %s' % table)
+            cursor.execute(f'DROP TABLE IF EXISTS {table}')
         conn.commit()
         conn.close()
 
@@ -347,12 +348,12 @@ class Backend(Database):
 
     def tag_alerts(self, query=None, tags=None):
         query = query or Query()
-        update = """
+        update = f"""
             UPDATE alerts
             SET tags=ARRAY(SELECT DISTINCT UNNEST(tags || %(_tags)s))
-            WHERE {where}
+            WHERE {query.where}
             RETURNING id
-        """.format(where=query.where)
+        """
         return [row[0] for row in self._updateall(update, {**query.vars, **{'_tags': tags}}, returning=True)]
 
     def untag_alerts(self, query=None, tags=None):
@@ -366,21 +367,21 @@ class Backend(Database):
         return [row[0] for row in self._updateall(update, {**query.vars, **{'_tags': tags}}, returning=True)]
 
     def update_attributes_by_query(self, query=None, attributes=None):
-        update = """
+        update = f"""
             UPDATE alerts
             SET attributes=attributes || %(_attributes)s
-            WHERE {where}
+            WHERE {query.where}
             RETURNING id
-        """.format(where=query.where)
+        """
         return [row[0] for row in self._updateall(update, {**query.vars, **{'_attributes': attributes}}, returning=True)]
 
     def delete_alerts(self, query=None):
         query = query or Query()
-        delete = """
+        delete = f"""
             DELETE FROM alerts
-            WHERE {where}
+            WHERE {query.where}
             RETURNING id
-        """.format(where=query.where)
+        """
         return [row[0] for row in self._deleteall(delete, query.vars, returning=True)]
 
     # SEARCH & HISTORY
@@ -412,18 +413,18 @@ class Backend(Database):
         join = ''
         if 's.code' in query.sort:
             join += 'JOIN (VALUES {}) AS s(sev, code) ON alerts.severity = s.sev '.format(
-                ', '.join(("('{}', {})".format(k, v) for k, v in alarm_model.Severity.items()))
+                ', '.join((f"('{k}', {v})" for k, v in alarm_model.Severity.items()))
             )
         if 'st.state' in query.sort:
             join += 'JOIN (VALUES {}) AS st(sts, state) ON alerts.status = st.sts '.format(
-                ', '.join(("('{}', '{}')".format(k, v) for k, v in alarm_model.Status.items()))
+                ', '.join((f"('{k}', '{v}')" for k, v in alarm_model.Status.items()))
             )
-        select = """
+        select = f"""
             SELECT {select}
               FROM alerts {join}
-             WHERE {where}
-          ORDER BY {order}
-        """.format(select=select, join=join, where=query.where, order=query.sort or 'last_receive_time')
+             WHERE {query.where}
+          ORDER BY {query.sort or 'last_receive_time'}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_alert_history(self, alert, page=None, page_size=None):
@@ -505,10 +506,10 @@ class Backend(Database):
 
     def get_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM alerts
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def get_counts(self, query=None, group=None):
@@ -524,20 +525,20 @@ class Backend(Database):
 
     def get_counts_by_severity(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT severity, COUNT(*) FROM alerts
-             WHERE {where}
+             WHERE {query.where}
             GROUP BY severity
-        """.format(where=query.where)
+        """
         return {s.severity: s.count for s in self._fetchall(select, query.vars)}
 
     def get_counts_by_status(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT status, COUNT(*) FROM alerts
-            WHERE {where}
+            WHERE {query.where}
             GROUP BY status
-        """.format(where=query.where)
+        """
         return {s.status: s.count for s in self._fetchall(select, query.vars)}
 
     def get_topn_count(self, query=None, group='event', topn=100):
@@ -557,8 +558,8 @@ class Backend(Database):
                 'duplicateCount': t.duplicate_count,
                 'environments': t.environments,
                 'services': t.services,
-                '%s' % group: t.event,
-                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url('/alert/%s' % r[0])} for r in t.resources]
+                f'{group}': t.event,
+                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url(f'/alert/{r[0]}')} for r in t.resources]
             } for t in self._fetchall(select, query.vars, limit=topn)
         ]
 
@@ -581,7 +582,7 @@ class Backend(Database):
                 'environments': t.environments,
                 'services': t.services,
                 'event': t.event,
-                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url('/alert/%s' % r[0])} for r in t.resources]
+                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url(f'/alert/{r[0]}')} for r in t.resources]
             } for t in self._fetchall(select, query.vars, limit=topn)
         ]
 
@@ -605,7 +606,7 @@ class Backend(Database):
                 'environments': t.environments,
                 'services': t.services,
                 'event': t.event,
-                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url('/alert/%s' % r[0])} for r in t.resources]
+                'resources': [{'id': r[0], 'resource': r[1], 'href': absolute_url(f'/alert/{r[0]}')} for r in t.resources]
             } for t in self._fetchall(select, query.vars, limit=topn)
         ]
 
@@ -613,11 +614,11 @@ class Backend(Database):
 
     def get_environments(self, query=None, topn=1000):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT environment, severity, status, count(1) FROM alerts
-            WHERE {where}
+            WHERE {query.where}
             GROUP BY environment, CUBE(severity, status)
-        """.format(where=query.where)
+        """
         result = self._fetchall(select, query.vars, limit=topn)
 
         severity_count = defaultdict(list)
@@ -680,11 +681,11 @@ class Backend(Database):
 
     def get_alert_groups(self, query=None, topn=1000):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT environment, "group", count(1) FROM alerts
-            WHERE {where}
+            WHERE {query.where}
             GROUP BY environment, "group"
-        """.format(where=query.where)
+        """
         return [
             {
                 'environment': g.environment,
@@ -707,17 +708,20 @@ class Backend(Database):
 
     def create_blackout(self, blackout):
         insert = """
-            INSERT INTO blackouts (id, priority, environment, service, resource, event, "group", tags,
-                customer, start_time, end_time, duration, "user", create_time, text)
-            VALUES (%(id)s, %(priority)s, %(environment)s, %(service)s, %(resource)s, %(event)s, %(group)s, %(tags)s,
-                %(customer)s, %(start_time)s, %(end_time)s, %(duration)s, %(user)s, %(create_time)s, %(text)s)
-            RETURNING *
+            INSERT INTO blackouts (id, priority, environment, service, resource, event,
+                "group", tags, origin, customer, start_time, end_time,
+                duration, "user", create_time, text)
+            VALUES (%(id)s, %(priority)s, %(environment)s, %(service)s, %(resource)s, %(event)s,
+                %(group)s, %(tags)s, %(origin)s, %(customer)s, %(start_time)s, %(end_time)s,
+                %(duration)s, %(user)s, %(create_time)s, %(text)s)
+            RETURNING *, duration AS remaining
         """
         return self._insert(insert, vars(blackout))
 
     def get_blackout(self, id, customers=None):
         select = """
-            SELECT * FROM blackouts
+            SELECT *, GREATEST(EXTRACT(EPOCH FROM (end_time - GREATEST(start_time, NOW() at time zone 'utc'))), 0) AS remaining
+            FROM blackouts
             WHERE id=%(id)s
               AND {customer}
         """.format(customer='customer=ANY(%(customers)s)' if customers else '1=1')
@@ -726,7 +730,8 @@ class Backend(Database):
     def get_blackouts(self, query=None, page=None, page_size=None):
         query = query or Query()
         select = """
-            SELECT * FROM blackouts
+            SELECT *, GREATEST(EXTRACT(EPOCH FROM (end_time - GREATEST(start_time, NOW() at time zone 'utc'))), 0) AS remaining
+              FROM blackouts
              WHERE {where}
           ORDER BY {order}
         """.format(where=query.where, order=query.sort)
@@ -734,10 +739,10 @@ class Backend(Database):
 
     def get_blackouts_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM blackouts
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def is_blackout_period(self, alert):
@@ -747,39 +752,71 @@ class Backend(Database):
             WHERE start_time <= %(create_time)s AND end_time > %(create_time)s
               AND environment=%(environment)s
               AND (
-                 (resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}')
-              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' )
-              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' )
-              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' )
-              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' )
-              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' )
-              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' )
-              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' )
-              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}' )
-              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' )
-              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' )
-              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' )
-              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' )
-              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s )
-                )
+                 ( resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource IS NULL AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service='{}' AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event IS NULL AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group" IS NULL AND tags <@ %(tags)s AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags='{}' AND origin=%(origin)s )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin IS NULL )
+              OR ( resource=%(resource)s AND service <@ %(service)s AND event=%(event)s AND "group"=%(group)s AND tags <@ %(tags)s AND origin=%(origin)s )
+                 )
         """
         if current_app.config['CUSTOMER_VIEWS']:
             select += ' AND (customer IS NULL OR customer=%(customer)s)'
@@ -804,6 +841,8 @@ class Backend(Database):
             update += '"group"=%(group)s, '
         if 'tags' in kwargs:
             update += 'tags=%(tags)s, '
+        if 'origin' in kwargs:
+            update += 'origin=%(origin)s, '
         if 'customer' in kwargs:
             update += 'customer=%(customer)s, '
         if kwargs.get('startTime') is not None:
@@ -817,7 +856,7 @@ class Backend(Database):
         update += """
             "user"=COALESCE(%(user)s, "user")
             WHERE id=%(id)s
-            RETURNING *
+            RETURNING *, GREATEST(EXTRACT(EPOCH FROM (end_time - GREATEST(start_time, NOW() at time zone 'utc'))), 0) AS remaining
         """
         kwargs['id'] = id
         kwargs['user'] = kwargs.get('user')
@@ -839,13 +878,18 @@ class Backend(Database):
             VALUES (%(id)s, %(origin)s, %(tags)s, %(attributes)s, %(event_type)s, %(create_time)s, %(timeout)s, %(receive_time)s, %(customer)s)
             ON CONFLICT (origin, COALESCE(customer, '')) DO UPDATE
                 SET tags=%(tags)s, attributes=%(attributes)s, create_time=%(create_time)s, timeout=%(timeout)s, receive_time=%(receive_time)s
-            RETURNING *
+            RETURNING *,
+                   EXTRACT(EPOCH FROM (receive_time - create_time)) AS latency,
+                   EXTRACT(EPOCH FROM (NOW() - receive_time)) AS since
         """
         return self._upsert(upsert, vars(heartbeat))
 
     def get_heartbeat(self, id, customers=None):
         select = """
-            SELECT * FROM heartbeats
+            SELECT *,
+                   EXTRACT(EPOCH FROM (receive_time - create_time)) AS latency,
+                   EXTRACT(EPOCH FROM (NOW() - receive_time)) AS since
+              FROM heartbeats
              WHERE (id=%(id)s OR id LIKE %(like_id)s)
                AND {customer}
         """.format(customer='customer=%(customers)s' if customers else '1=1')
@@ -854,18 +898,56 @@ class Backend(Database):
     def get_heartbeats(self, query=None, page=None, page_size=None):
         query = query or Query()
         select = """
-            SELECT * FROM heartbeats
+            SELECT *,
+                   EXTRACT(EPOCH FROM (receive_time - create_time)) AS latency,
+                   EXTRACT(EPOCH FROM (NOW() - receive_time)) AS since
+              FROM heartbeats
              WHERE {where}
           ORDER BY {order}
         """.format(where=query.where, order=query.sort)
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
+    def get_heartbeats_by_status(self, status=None, query=None, page=None, page_size=None):
+        status = status or list()
+        query = query or Query()
+
+        swhere = ''
+        if status:
+            q = list()
+            if HeartbeatStatus.OK in status:
+                q.append(
+                    """
+                    (EXTRACT(EPOCH FROM (NOW() at time zone 'utc' - receive_time)) <= timeout
+                    AND EXTRACT(EPOCH FROM (receive_time - create_time)) * 1000 <= {max_latency})
+                    """.format(max_latency=current_app.config['HEARTBEAT_MAX_LATENCY']))
+            if HeartbeatStatus.Expired in status:
+                q.append("(EXTRACT(EPOCH FROM (NOW() at time zone 'utc' - receive_time)) > timeout)")
+            if HeartbeatStatus.Slow in status:
+                q.append(
+                    """
+                    (EXTRACT(EPOCH FROM (NOW() at time zone 'utc' - receive_time)) <= timeout
+                    AND EXTRACT(EPOCH FROM (receive_time - create_time)) * 1000 > {max_latency})
+                    """.format(max_latency=current_app.config['HEARTBEAT_MAX_LATENCY']))
+            if q:
+                swhere = 'AND (' + ' OR '.join(q) + ')'
+
+        select = """
+            SELECT *,
+                   EXTRACT(EPOCH FROM (receive_time - create_time)) AS latency,
+                   EXTRACT(EPOCH FROM (NOW() - receive_time)) AS since
+              FROM heartbeats
+             WHERE {where}
+             {swhere}
+          ORDER BY {order}
+        """.format(where=query.where, swhere=swhere, order=query.sort)
+        return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
+
     def get_heartbeats_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM heartbeats
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def delete_heartbeat(self, id):
@@ -887,20 +969,20 @@ class Backend(Database):
         return self._insert(insert, vars(key))
 
     def get_key(self, key, user=None):
-        select = """
+        select = f"""
             SELECT * FROM keys
              WHERE (id=%(key)s OR key=%(key)s)
-               AND {user}
-        """.format(user='"user"=%(user)s' if user else '1=1')
+               AND {'"user"=%(user)s' if user else '1=1'}
+        """
         return self._fetchone(select, {'key': key, 'user': user})
 
     def get_keys(self, query=None, page=None, page_size=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT * FROM keys
-             WHERE {where}
-          ORDER BY {order}
-        """.format(where=query.where, order=query.sort)
+             WHERE {query.where}
+          ORDER BY {query.sort}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_keys_by_user(self, user):
@@ -912,10 +994,10 @@ class Backend(Database):
 
     def get_keys_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM keys
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def update_key(self, key, **kwargs):
@@ -975,19 +1057,19 @@ class Backend(Database):
 
     def get_users(self, query=None, page=None, page_size=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT * FROM users
-             WHERE {where}
-          ORDER BY {order}
-        """.format(where=query.where, order=query.sort)
+             WHERE {query.where}
+          ORDER BY {query.sort}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_users_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM users
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def get_user_by_username(self, username):
@@ -1075,18 +1157,18 @@ class Backend(Database):
         insert = """
             INSERT INTO groups (id, name, text)
             VALUES (%(id)s, %(name)s, %(text)s)
-            RETURNING *
+            RETURNING *, 0 AS count
         """
         return self._insert(insert, vars(group))
 
     def get_group(self, id):
-        select = """SELECT * FROM groups WHERE id=%s"""
+        select = """SELECT *, COALESCE(CARDINALITY(users), 0) AS count FROM groups WHERE id=%s"""
         return self._fetchone(select, (id,))
 
     def get_groups(self, query=None, page=None, page_size=None):
         query = query or Query()
         select = """
-            SELECT * FROM groups
+            SELECT *, COALESCE(CARDINALITY(users), 0) AS count FROM groups
              WHERE {where}
           ORDER BY {order}
         """.format(where=query.where, order=query.sort)
@@ -1094,10 +1176,10 @@ class Backend(Database):
 
     def get_groups_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM groups
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def get_group_users(self, id):
@@ -1121,7 +1203,7 @@ class Backend(Database):
         update += """
             update_time=NOW() at time zone 'utc'
             WHERE id=%(id)s
-            RETURNING *
+            RETURNING *, COALESCE(CARDINALITY(users), 0) AS count
         """
         kwargs['id'] = id
         return self._updateone(update, kwargs, returning=True)
@@ -1154,7 +1236,8 @@ class Backend(Database):
 
     def get_groups_by_user(self, user):
         select = """
-            SELECT * FROM groups
+            SELECT *, COALESCE(CARDINALITY(users), 0) AS count
+              FROM groups
             WHERE %s=ANY(users)
         """
         return self._fetchall(select, (user,))
@@ -1175,19 +1258,19 @@ class Backend(Database):
 
     def get_perms(self, query=None, page=None, page_size=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT * FROM perms
-             WHERE {where}
-          ORDER BY {order}
-        """.format(where=query.where, order=query.sort)
+             WHERE {query.where}
+          ORDER BY {query.sort}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_perms_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM perms
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def update_perm(self, id, **kwargs):
@@ -1249,19 +1332,19 @@ class Backend(Database):
 
     def get_customers(self, query=None, page=None, page_size=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT * FROM customers
-             WHERE {where}
-          ORDER BY {order}
-        """.format(where=query.where, order=query.sort)
+             WHERE {query.where}
+          ORDER BY {query.sort}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_customers_count(self, query=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT COUNT(1) FROM customers
-             WHERE {where}
-        """.format(where=query.where)
+             WHERE {query.where}
+        """
         return self._fetchone(select, query.vars).count
 
     def update_customer(self, id, **kwargs):
@@ -1305,7 +1388,7 @@ class Backend(Database):
                 return '*'  # all customers
             return customers
 
-        raise NoCustomerMatch("No customer lookup configured for user '{}' or '{}'".format(login, ','.join(matches)))
+        raise NoCustomerMatch(f"No customer lookup configured for user '{login}' or '{','.join(matches)}'")
 
     # NOTES
 
@@ -1328,11 +1411,11 @@ class Backend(Database):
 
     def get_notes(self, query=None, page=None, page_size=None):
         query = query or Query()
-        select = """
+        select = f"""
             SELECT * FROM notes
-             WHERE {where}
-          ORDER BY {order}
-        """.format(where=query.where, order=query.sort or 'create_time')
+             WHERE {query.where}
+          ORDER BY {query.sort or 'create_time'}
+        """
         return self._fetchall(select, query.vars, limit=page_size, offset=(page - 1) * page_size)
 
     def get_alert_notes(self, id, page=None, page_size=None):
@@ -1417,14 +1500,14 @@ class Backend(Database):
     # HOUSEKEEPING
 
     def get_expired(self, expired_threshold, info_threshold):
-        # delete 'closed' or 'expired' alerts older than "expired_threshold" hours
-        # and 'informational' alerts older than "info_threshold" hours
+        # delete 'closed' or 'expired' alerts older than "expired_threshold" seconds
+        # and 'informational' alerts older than "info_threshold" seconds
 
         if expired_threshold:
             delete = """
                 DELETE FROM alerts
                  WHERE (status IN ('closed', 'expired')
-                        AND last_receive_time < (NOW() at time zone 'utc' - INTERVAL '%(expired_threshold)s hours'))
+                        AND last_receive_time < (NOW() at time zone 'utc' - INTERVAL '%(expired_threshold)s seconds'))
             """
             self._deleteall(delete, {'expired_threshold': expired_threshold})
 
@@ -1432,7 +1515,7 @@ class Backend(Database):
             delete = """
                 DELETE FROM alerts
                  WHERE (severity='informational'
-                        AND last_receive_time < (NOW() at time zone 'utc' - INTERVAL '%(info_threshold)s hours'))
+                        AND last_receive_time < (NOW() at time zone 'utc' - INTERVAL '%(info_threshold)s seconds'))
             """
             self._deleteall(delete, {'info_threshold': info_threshold})
 
@@ -1501,7 +1584,7 @@ class Backend(Database):
         """
         if limit is None:
             limit = current_app.config['DEFAULT_PAGE_SIZE']
-        query += ' LIMIT %s OFFSET %s''' % (limit, offset)
+        query += f' LIMIT {limit} OFFSET {offset}'
         cursor = self.get_db().cursor()
         self._log(cursor, query, vars)
         cursor.execute(query, vars)
