@@ -76,16 +76,16 @@ def properties():
     properties = ''
 
     for k, v in request.environ.items():
-        properties += '{}: {}\n'.format(k, v)
+        properties += f'{k}: {v}\n'
 
     for k, v in os.environ.items():
-        properties += '{}: {}\n'.format(k, v)
+        properties += f'{k}: {v}\n'
 
     for k, v in current_app.__dict__.items():
-        properties += '{}: {}\n'.format(k, v)
+        properties += f'{k}: {v}\n'
 
     for k, v in current_app.config.items():
-        properties += '{}: {}\n'.format(k, v)
+        properties += f'{k}: {v}\n'
 
     return Response(properties, content_type='text/plain')
 
@@ -133,10 +133,10 @@ def health_check():
             delta = datetime.datetime.utcnow() - heartbeat.receive_time
             threshold = int(heartbeat.timeout) * 4
             if delta.seconds > threshold:
-                return 'HEARTBEAT_STALE: %s' % heartbeat.origin, 503
+                return f'HEARTBEAT_STALE: {heartbeat.origin}', 503
 
     except Exception as e:
-        return 'HEALTH_CHECK_FAILED: %s' % e, 503
+        return f'HEALTH_CHECK_FAILED: {e}', 503
 
     return 'OK'
 
@@ -145,8 +145,18 @@ def health_check():
 @cross_origin()
 @permission(Scope.admin_management)
 def housekeeping():
-    expired_threshold = request.args.get('expired', default=current_app.config['DEFAULT_EXPIRED_DELETE_HRS'], type=int)
-    info_threshold = request.args.get('info', default=current_app.config['DEFAULT_INFO_DELETE_HRS'], type=int)
+    expired_threshold_hrs = request.args.get('expired', type=int)
+    info_threshold_hrs = request.args.get('info', type=int)
+
+    if expired_threshold_hrs:
+        expired_threshold = expired_threshold_hrs * 60 * 60  # convert hours to seconds
+    else:
+        expired_threshold = current_app.config['DELETE_EXPIRED_AFTER']  # seconds
+
+    if info_threshold_hrs:
+        info_threshold = info_threshold_hrs * 60 * 60  # convert hours to seconds
+    else:
+        info_threshold = current_app.config['DELETE_INFO_AFTER']  # seconds
 
     has_expired, shelve_timeout, ack_timeout = Alert.housekeeping(expired_threshold, info_threshold)
 
