@@ -20,6 +20,12 @@ class HeartbeatReceiver(PluginBase):
             hb = Heartbeat(
                 origin=alert.origin,
                 tags=alert.tags,
+                attributes={
+                    'environment': alert.environment,
+                    'severity': alert.severity,
+                    'service': alert.service,
+                    'group': alert.group
+                },
                 timeout=alert.timeout,
                 customer=alert.customer
             )
