@@ -2,6 +2,8 @@ import json
 from datetime import datetime
 from typing import Any, Dict
 
+from flask import current_app
+
 from alerta.app import alarm_model
 from alerta.models.alert import Alert
 
@@ -34,7 +36,7 @@ class CloudWatchWebhook(WebhookBase):
             return Alert(
                 resource=notification['TopicArn'],
                 event=notification['Type'],
-                environment='Production',
+                environment=current_app.config['DEFAULT_ENVIRONMENT'],
                 severity='informational',
                 service=['Unknown'],
                 group='AWS/CloudWatch',
