@@ -1,5 +1,7 @@
 from typing import Any, Dict
 
+from flask import current_app
+
 from alerta.models.alert import Alert
 
 from . import WebhookBase
@@ -16,9 +18,9 @@ class RiemannWebhook(WebhookBase):
     def incoming(self, path, query_string, payload):
 
         return Alert(
-            resource='{}-{}'.format(payload['host'], payload['service']),
+            resource=f"{payload['host']}-{payload['service']}",
             event=payload.get('event', payload['service']),
-            environment=payload.get('environment', 'Production'),
+            environment=payload.get('environment', current_app.config['DEFAULT_ENVIRONMENT']),
             severity=payload.get('state', 'unknown'),
             service=[payload['service']],
             group=payload.get('group', 'Performance'),
