@@ -1,5 +1,7 @@
 from typing import Any, Dict
 
+from flask import current_app
+
 from alerta.models.alert import Alert
 
 from . import WebhookBase
@@ -23,12 +25,12 @@ class ServerDensityWebhook(WebhookBase):
         return Alert(
             resource=payload['item_name'],
             event=payload['alert_type'],
-            environment='Production',
+            environment=current_app.config['DEFAULT_ENVIRONMENT'],
             severity=severity,
             service=[payload['item_type']],
             group=payload['alert_section'],
             value=payload['configured_trigger_value'],
-            text='Alert created for {}:{}'.format(payload['item_type'], payload['item_name']),
+            text=f"Alert created for {payload['item_type']}:{payload['item_name']}",
             tags=['cloud'] if payload['item_cloud'] else [],
             attributes={
                 'alertId': payload['alert_id'],
