@@ -1,5 +1,4 @@
 import json
-from datetime import datetime
 from typing import Any, Dict
 
 from flask import current_app
@@ -17,7 +16,7 @@ class StackDriverWebhook(WebhookBase):
     See https://cloud.google.com/monitoring/support/notification-options#webhooks
     """
 
-    def incoming(self, query_string, payload):
+    def incoming(self, path, query_string, payload):
 
         incident = payload['incident']
         state = incident['state']
@@ -29,30 +28,28 @@ class StackDriverWebhook(WebhookBase):
                 content = json.loads(incident['documentation']['content'])
                 incident.update(content)
             except Exception:
-                current_app.logger.warning("Invalid documentation content: '{}'".format(incident['documentation']))
+                current_app.logger.warning(f"Invalid documentation content: '{incident['documentation']}'")
 
-        service = []
         status = None
-        create_time = None  # type: ignore
         severity = incident.get('severity', 'critical')
 
-        if incident['policy_name']:
-            service.append(incident['policy_name'])
-
         if state == 'open':
-            create_time = datetime.utcfromtimestamp(incident['started_at'])
+            status = None
         elif state == 'acknowledged':
             status = 'ack'
         elif state == 'closed':
             severity = 'ok'
-            create_time = datetime.utcfromtimestamp(incident['ended_at'])
         else:
             severity = 'indeterminate'
 
+        service = []
+        if incident['policy_name']:
+            service.append(incident['policy_name'])
+
         return Alert(
             resource=incident['resource_name'],
             event=incident['condition_name'],
-            environment=incident.get('environment', 'Production'),
+            environment=incident.get('environment', current_app.config['DEFAULT_ENVIRONMENT']),
             severity=severity,
             status=status,
             service=service,
@@ -61,11 +58,13 @@ class StackDriverWebhook(WebhookBase):
             attributes={
                 'incidentId': incident['incident_id'],
                 'resourceId': incident['resource_id'],
-                'moreInfo': '<a href="%s" target="_blank">Stackdriver Console</a>' % incident['url']
+                'moreInfo': f"<a href=\"{incident['url']}\" target=\"_blank\">Stackdriver Console</a>",
+                'startedAt': incident['started_at'],
+                'endedAt': incident['ended_at']
+
             },
             customer=incident.get('customer'),
             origin=incident.get('origin', 'Stackdriver'),
             event_type='stackdriverAlert',
-            create_time=create_time,
             raw_data=payload
         )
